@@ -1,13 +1,15 @@
 import re
 from typing import Optional
 
+from ..exceptions import InvalidWidgetIdError
+
 ID_PATTERN = re.compile("^[a-zA-Z0-9_.]+$")
 
 
 class Actionable:
     def __init__(self, id: Optional[str] = None):
         if id and not ID_PATTERN.match(id):
-            raise ValueError(f"Invalid widget id: {id}")
+            raise InvalidWidgetIdError(f"Invalid widget id: {id}")
         self.widget_id = id
 
     def find(self, widget_id):
