@@ -1,6 +1,6 @@
 from typing import Union, Callable, Any
 
-from aiogram_dialog.manager.intent import ChatEvent
+from aiogram_dialog.context.events import ChatEvent
 from aiogram_dialog.manager.protocols import DialogManager
 
 
